Tortured Confessions Ithaca, New York April 25th 2003 10 players Peter Bakija "But Where are Kim and Kelly Deal?" Crypt (12 cards, min=14, max=30, avg=5.67) ------------------------------------------ 2x Selma the Repugnant 8 OBF POT ani for prince Nosferatu:1 2x Murat 7 OBF POT ser prince Nosferatu:2 2x Nikolaus Vermeulen 7 POT ani for obf prince Nosferatu:2 2x Calebros, The Martyr 5 ANI obf pot prince Nosferatu:2 2x Laurent de Valois 4 ani dom obf Nosferatu:2 1x Agrippina 4 OBF pot Nosferatu:1 1x Dimple 2 obf Nosferatu:1 Library (90 cards) Master (16) 3x Blood Doll 1x Dominate 8x Obfuscate 1x Powerbase: Montreal 1x Powerbase: Rome 1x Secret Library of Alexandria, The 1x Slum Hunting Ground Action (16) 6x Night Moves 10x Third Tradition: Progeny Political Action (24) 3x Ancilla Empowerment 12x Consanguineous Boon 1x Kindred Restructure 2x Nosferatu Justicar 2x Parity Shift 1x Praxis Seizure: Atlanta 1x Praxis Seizure: Boston 1x Praxis Seizure: Chicago 1x Praxis Seizure: Cleveland Action Modifier (14) 6x Lost in Crowds 8x Spying Mission Action Modifier/Combat (6) 6x Swallowed by the Night Reaction (8) 6x Deflection 2x Second Tradition: Domain Combat (6) 6x Behind You!